Admin — Poezio 0.9-dev documentation

# Admin

This plugin adds several convenient aliases, to shorten roles/affiliation management.

## Aliases defined

All those commands take a nick or a JID as a parameter.

### For roles

/moderator
/op
  Set the role to `moderator`
/participant
  Set the role to `participant`
/visitor
/mute
  Set the role to `visitor`

### For affiliations

/admin
  Set the affiliation to `admin`
/member
/voice
  Set the affiliation to `member`
/noaffiliation
  Set the affiliation to `none`
/owner
  Set the affiliation to `owner`